﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Telerik.WinControls;

namespace RadControlsExample
{
    public class MyShortcutProvider : IShortcutProvider
    {
        private Form1 form;
        private RadShortcutCollection shortcuts;
        private bool registered;

        public MyShortcutProvider(Form1 form)
        {
            this.form = form;
            this.shortcuts = new RadShortcutCollection(this);
        }

        #region IShortcutProvider Members

        public void OnPartialShortcut(PartialShortcutEventArgs e)
        {
            //This callback is called when a key that partially matches a registered shortcut is pressed
            //For example if we have CTRL + A, S pressing CTRL + A will execute this callback.
            //You will need to set the PartialShortcutEventArgs.Handled to true if you want to wait for the complete keyboard combination
            e.Handled = true;
        }

        public void OnShortcut(ShortcutEventArgs e)
        {
            //A keyboard combination for a specific shortcut is pressed.
            //Mark the event arguments as "Handled" so that this shortcut is no further processed.
            if (e.Shortcut.KeyMappings.Length == 1 && e.Shortcut.KeyMappings[0] == Keys.F1)
            {
                if (this.form.DropDownButton.DropDownButtonElement.IsDropDownShown)
                {
                    this.form.DropDownButton.DropDownButtonElement.HideDropDown();
                }
                else
                {
                    this.form.DropDownButton.DropDownButtonElement.ShowDropDown();
                }

                e.Handled = true;
            }
            else if (this.form.DropDownButton.DropDownButtonElement.IsDropDownShown && e.Shortcut.KeyMappings.Length == 1 &&
                e.Shortcut.KeyMappings[0] > Keys.D0 && e.Shortcut.KeyMappings[0] <= Keys.D9 &&
                ((int)e.Shortcut.KeyMappings[0] - (int)Keys.D1) <= this.form.DropDownButton.Items.Count)
            {
                int number = (int)e.Shortcut.KeyMappings[0] - (int)Keys.D1;
                this.form.DropDownButton.Items[number].PerformClick();
                this.form.DropDownButton.DropDownButtonElement.HideDropDown();
                e.Handled = true;
            }
        }

        public void OnShortcutsChanged()
        {
            //Called by the Shortcuts collection when a shortcut is either added or removed from the collection
            //This is used for optimization purposes - e.g. is we do not have shortcuts registered,
            //we do not need to be registered with RadShortcutManager
            if (this.shortcuts.Count > 0)
            {
                if (!this.registered)
                {
                    RadShortcutManager.Instance.AddShortcutProvider(this);
                    this.registered = true;
                }
            }
            else
            {
                if (this.registered)
                {
                    RadShortcutManager.Instance.RemoveShortcutProvider(this);
                    this.registered = false;
                }
            }
        }

        public RadShortcutCollection Shortcuts
        {
            get { return this.shortcuts; }
        }

        #endregion
    }
}
